<?php

namespace Drupal\licenses\Plugin\License\Scanner;

use Composer\Spdx\SpdxLicenses;
use Drupal\licenses\License;
use Drupal\licenses\LicensePluginBase;

/**
 * Plugin implementation of the license.
 *
 * @License(
 *   id = "nodejs",
 *   label = @Translation("Node.js"),
 *   description = @Translation("Node.js defined libraries licenses.")
 * )
 */
class Nodejs extends LicensePluginBase implements ScannerInterface {

  /**
   * An array of licenses.
   *
   * @var \Drupal\licenses\License[]
   */
  protected $licenses = [];

  /**
   * {@inheritdoc}
   */
  public function scan() {
    $spdx = new SpdxLicenses();

    $themes = \Drupal::service('theme_handler')->listInfo();
    foreach ($themes as $machine_name => $theme) {
      $filename = implode(DIRECTORY_SEPARATOR, [DRUPAL_ROOT, drupal_get_path('theme', $machine_name), 'package-lock.json']);
      if (!file_exists($filename)) {
        continue;
      }

      $libraries = json_decode(file_get_contents($filename));
      foreach ($libraries->dependencies as $library_machine_name => $library) {
        // $package_definition_url = explode('/-/', $library->resolved)[0];
        // $package_definition = json_decode(file_get_contents($package_definition_url));

        $license = new License();
        $identifier = 'n/a';
        $spdx_license = $spdx->getLicenseByIdentifier($identifier);

        $license
          ->setIdentifier($identifier)
          ->setLibraryName($library_machine_name)
          ->setLibraryVersion((string) $library->version)
          // ->setLibraryHomepage((string) $package_definition->versions->{"$library->version"}->homepage)
          ->setFilename($filename);
        if (isset($spdx_license)) {
          $license
            ->setFullName((string) $spdx_license[0])
            ->setOsiCertified((bool) $spdx_license[1])
            ->setUri((string) $spdx_license[2])
            ->setDeprecated((bool) $spdx_license[3]);
        }
        array_push($this->licenses, $license);
      }
    }
    return $this->licenses;
  }

}
